@@ -50,10 +50,11 @@
 package com.openexchange.util.activator.impl;
 
 import java.lang.reflect.Constructor;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import javax.annotation.concurrent.Immutable;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 
 /**
  * {@link ConstructorServiceWithDependencies}
@@ -63,7 +64,6 @@ import com.google.common.collect.ImmutableSet;
  * @param <S>
  * @param <T>
  */
-@ParametersAreNonnullByDefault
 @Immutable
 public final class ConstructorServiceWithDependencies<S, T extends S> extends ClassServiceWithDependenciesTemplate<S, T> {
     
