@@ -49,12 +49,14 @@
 
 package com.openexchange.util.activator.impl;
 
+import static com.openexchange.util.custom.base.NullUtil.absent;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import com.google.common.base.Optional;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 import com.openexchange.util.activator.ServiceRef;
 
@@ -65,18 +67,17 @@ import com.openexchange.util.activator.ServiceRef;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.2
  */
-@ParametersAreNonnullByDefault
 public enum EmptyServiceDependencyResolver implements ServiceDependencyResolver {
     INSTANCE;
 
     @Override
     public Optional<Object[]> resolveParameters(Constructor<?> constructor) {
-        return Optional.absent();
+        return absent();
     }
 
     @Override
     public Optional<Object[]> resolveParameters(Method method) {
-        return Optional.absent();
+        return absent();
     }
 
     @Override
@@ -86,7 +87,6 @@ public enum EmptyServiceDependencyResolver implements ServiceDependencyResolver
 
     @Override
     public @Nullable <X> ServiceRef<X> resolveOptionalService(Class<X> serviceClass, @Nullable Annotation[] annotations) {
-        // TODO Auto-generated method stub
         return null;
     }
 
