@@ -53,12 +53,13 @@ import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.lang.reflect.Constructor;
 import java.util.Dictionary;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import javax.annotation.concurrent.ThreadSafe;
 import org.osgi.framework.BundleContext;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.ServiceDependencyResolver;
@@ -71,7 +72,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  */
 @ThreadSafe
-@ParametersAreNonnullByDefault
 public class ServiceAwareDependentServiceRegisterer<S, T extends S> extends InstanceFactoryServiceAwareDependentServiceRegistererTemplate<S, T> {
 
     private final @Nullable ServiceRegistrationHandler<T> serviceRegistrationHandler;        
