@@ -55,7 +55,6 @@ import static com.openexchange.util.custom.base.NullUtil.immutableSetCopyOf;
 import static com.openexchange.util.custom.base.NullUtil.listBuilder;
 import static com.openexchange.util.custom.base.NullUtil.logger;
 import static com.openexchange.util.custom.base.NullUtil.mapBuilder;
-import static java.util.stream.Collectors.joining;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Dictionary;
@@ -67,11 +66,10 @@ import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.locks.ReentrantLock;
-
-
 import javax.annotation.concurrent.ThreadSafe;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
+import org.slf4j.Logger;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
@@ -96,7 +94,9 @@ import com.openexchange.util.custom.collect.ImmutableDictionary;
 @ThreadSafe
 public abstract class ServiceAwareDependentServiceRegistererTemplate<S, T extends S> implements ExtendedServiceTrackerCustomizer<S, T> {
 
-    private static final org.slf4j.Logger LOG = logger(ServiceAwareDependentServiceRegistererTemplate.class);
+    private static final Logger LOG = logger(ServiceAwareDependentServiceRegistererTemplate.class);
+    @SuppressWarnings("null")
+    private static final String NL = String.format("%n");
     
     private static final class ResolvedService {
         public final Object serviceObject; 
@@ -244,9 +244,12 @@ public abstract class ServiceAwareDependentServiceRegistererTemplate<S, T extend
         }
         if (! unresolvedMandatoryServiceDependencies.isEmpty()) {
             if (LOG.isTraceEnabled()) {
-                LOG.trace("{} has {} unresolved mandatory service dependencies: {}", serviceInstanceName,
-                    unresolvedMandatoryServiceDependencies.size(),
-                    unresolvedMandatoryServiceDependencies.stream().map(d -> d.identify()).collect(joining(", ")));
+                final StringBuilder b = new StringBuilder();
+                b.append(serviceInstanceName).append(" has ").append(unresolvedMandatoryServiceDependencies.size()).append(" unresolved dependencies:");
+                for (final ServiceDependency<?> dependency : unresolvedMandatoryServiceDependencies) {
+                    b.append(NL).append("- ").append(dependency.identify());
+                }
+                LOG.trace(b.toString());
             }
             needsRegistration = false;
         }
