@@ -51,9 +51,10 @@ package com.openexchange.util.activator.impl;
 
 import java.lang.annotation.Annotation;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import org.osgi.framework.ServiceReference;
+import com.openexchange.annotation.Nullable;
 
 
 /**
@@ -62,7 +63,6 @@ import org.osgi.framework.ServiceReference;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.1
  */
-@ParametersAreNonnullByDefault
 public interface ServiceDependency<S> {
     
     String identify();
