@@ -49,18 +49,18 @@
 
 package com.openexchange.util.activator.impl;
 
+import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
 import java.util.Dictionary;
 import java.util.List;
 import java.util.Map;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import javax.annotation.concurrent.Immutable;
 import com.google.common.base.Optional;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.ServiceDependencyResolver;
@@ -74,7 +74,6 @@ import com.openexchange.util.custom.collect.ImmutableDictionary;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v7.8.2
  */
-@ParametersAreNonnullByDefault
 @Immutable
 public final class ServiceDependencyResolverImpl implements ServiceDependencyResolver {
 
@@ -89,10 +88,10 @@ public final class ServiceDependencyResolverImpl implements ServiceDependencyRes
         Map<Class<?>, ServiceSet<?>> serviceSets,
         Map<Class<?>, ServiceListing<?>> serviceListings,
         Map<String, ?> properties) {
-        this.mandatoryDependencies = ImmutableMap.copyOf(mandatoryDependencies);
-        this.optionalDependencies = ImmutableList.copyOf(optionalDependencies);
-        this.serviceSets = ImmutableMap.copyOf(serviceSets);
-        this.serviceListings = ImmutableMap.copyOf(serviceListings);
+        this.mandatoryDependencies = immutableCopyOf(mandatoryDependencies);
+        this.optionalDependencies = immutableCopyOf(optionalDependencies);
+        this.serviceSets = immutableCopyOf(serviceSets);
+        this.serviceListings = immutableCopyOf(serviceListings);
         this.properties = ImmutableDictionary.copyOf(properties);
     }
 
@@ -101,10 +100,10 @@ public final class ServiceDependencyResolverImpl implements ServiceDependencyRes
         Map<Class<?>, ServiceSet<?>> serviceSets,
         Map<Class<?>, ServiceListing<?>> serviceListings,
         Dictionary<String, ?> properties) {
-        this.mandatoryDependencies = ImmutableMap.copyOf(mandatoryDependencies);
-        this.optionalDependencies = ImmutableList.copyOf(optionalDependencies);
-        this.serviceSets = ImmutableMap.copyOf(serviceSets);
-        this.serviceListings = ImmutableMap.copyOf(serviceListings);
+        this.mandatoryDependencies = immutableCopyOf(mandatoryDependencies);
+        this.optionalDependencies = immutableCopyOf(optionalDependencies);
+        this.serviceSets = immutableCopyOf(serviceSets);
+        this.serviceListings = immutableCopyOf(serviceListings);
         this.properties = ImmutableDictionary.copyOf(properties);
     }
     
