@@ -49,9 +49,11 @@
 
 package com.openexchange.util.activator.impl;
 
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
+import static com.openexchange.util.custom.base.NullUtil.emptySet;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 
 
@@ -61,7 +63,6 @@ import com.openexchange.util.activator.ServiceDependencyResolver;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.2
  */
-@ParametersAreNonnullByDefault
 public class ServiceInstanceServiceWithDependencies<S, T extends S> extends ServiceWithDependenciesTemplate<S, T> {
 
     protected final T serviceInstance;
@@ -73,10 +74,10 @@ public class ServiceInstanceServiceWithDependencies<S, T extends S> extends Serv
         super(
             (Class<T>) serviceInstance.getClass(),
             optServiceClass,
-            mandatoryDependencies != null ? mandatoryDependencies : ImmutableSet.<MandatoryServiceDependency<?>>of(),
-            optionalDependencies != null ? optionalDependencies : ImmutableSet.<OptionalServiceDependency<?>>of(),
-            ImmutableSet.<Class<?>>of(),
-            ImmutableSet.<Class<?>>of()
+            mandatoryDependencies != null ? mandatoryDependencies : emptySet(),
+            optionalDependencies != null ? optionalDependencies : emptySet(),
+            emptySet(),
+            emptySet()
         );
         this.serviceInstance = serviceInstance;
     }
