@@ -54,23 +54,24 @@ import static com.openexchange.util.activator.impl.RegistrationTools.serviceList
 import static com.openexchange.util.activator.impl.RegistrationTools.serviceSets;
 import static com.openexchange.util.activator.impl.RegistrationTools.trackAndOpen;
 import static com.openexchange.util.activator.impl.RegistrationTools.whatIsProvidedBy;
+import static com.openexchange.util.custom.base.NullUtil.emptyList;
+import static com.openexchange.util.custom.base.NullUtil.emptyMap;
 import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.util.Dictionary;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import javax.annotation.concurrent.Immutable;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTracker;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.google.common.base.Optional;
-import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.ServiceDependencyResolver;
 import com.openexchange.util.activator.ServiceRegistrationHandler;
+import com.openexchange.util.custom.base.NullUtil;
 
 /**
  * {@link ServiceWithDependenciesTemplate}
@@ -80,7 +81,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @param <S>
  * @param <T>
  */
-@ParametersAreNonnullByDefault
 @Immutable
 public abstract class ServiceWithDependenciesTemplate<S, T extends S> implements ServiceWithDependencies<T> {
     
@@ -98,7 +98,9 @@ public abstract class ServiceWithDependenciesTemplate<S, T extends S> implements
         ImmutableSet<Class<?>> serviceSets,
         ImmutableSet<Class<?>> serviceListings) {
         this.serviceInstanceClass = serviceInstanceClass;
-        this.optServiceClass = Optional.fromNullable(serviceClass);
+        {
+            this.optServiceClass = NullUtil.optionalFromNullable(serviceClass);
+        }
         this.mandatoryDependencies = mandatoryDependencies;
         this.optionalDependencies = optionalDependencies;
         this.serviceSets = serviceSets;
@@ -116,8 +118,8 @@ public abstract class ServiceWithDependenciesTemplate<S, T extends S> implements
                 final ImmutableMap<Class<?>, ServiceSet<?>> serviceSetMap = serviceSets(bundleContext, registry, serviceSets);
                 final ImmutableMap<Class<?>, ServiceListing<?>> serviceListingMap = serviceListings(bundleContext, registry, serviceListings);
                 resolver = new ServiceDependencyResolverImpl(
-                    ImmutableMap.<MandatoryServiceDependency<?>, Object>of(),
-                    ImmutableList.<OptionalServiceDependency<?>>of(),
+                    emptyMap(),
+                    emptyList(),
                     serviceSetMap,
                     serviceListingMap,
                     properties
