@@ -49,15 +49,16 @@
 
 package com.openexchange.util.activator.impl;
 
+import static com.openexchange.util.custom.base.NullUtil.build;
 import static com.openexchange.util.custom.base.NullUtil.className;
+import static com.openexchange.util.custom.base.NullUtil.emptySet;
 import java.util.Dictionary;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import javax.servlet.http.HttpServlet;
 import org.osgi.framework.BundleContext;
 import org.osgi.service.http.HttpService;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.util.activator.DependencyProvider;
 import com.openexchange.util.activator.ServiceDependencyResolver;
@@ -70,7 +71,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.0
  */
-@ParametersAreNonnullByDefault
 public class ServletInstanceServiceWithDependencies<T extends HttpServlet> extends ServiceInstanceServiceWithDependencies<HttpServlet, T> {
 
     private static final ImmutableSet<MandatoryServiceDependency<?>> deps(final String path) {
@@ -79,7 +79,7 @@ public class ServletInstanceServiceWithDependencies<T extends HttpServlet> exten
         if (path.contains("${")) {
             b.add(new MandatoryServiceDependency<>(ConfigurationService.class));
         }
-        return b.build();
+        return build(b);
     }
     
     private final String path;
@@ -102,8 +102,8 @@ public class ServletInstanceServiceWithDependencies<T extends HttpServlet> exten
             properties,
             mandatoryDependencies,
             optionalDependencies,
-            RegistrationTools.serviceSets(bundleContext, registry, ImmutableSet.<Class<?>>of()),
-            RegistrationTools.serviceListings(bundleContext, registry, ImmutableSet.<Class<?>>of()),
+            RegistrationTools.serviceSets(bundleContext, registry, emptySet()),
+            RegistrationTools.serviceListings(bundleContext, registry, emptySet()),
             RegistrationTools.collectPropertiesOfInterest(mandatoryDependencies, optionalDependencies)) {
             @Override
             protected T createInstance(final ServiceDependencyResolver resolver)
