@@ -53,13 +53,14 @@ import static com.openexchange.util.custom.base.NullUtil.className;
 import java.lang.reflect.Constructor;
 import java.util.Dictionary;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
+
 import javax.annotation.concurrent.ThreadSafe;
 import javax.servlet.http.HttpServlet;
 import org.osgi.framework.BundleContext;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.osgi.ServiceListing;
 import com.openexchange.osgi.ServiceSet;
 import com.openexchange.util.activator.ServiceDependencyResolver;
@@ -72,7 +73,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  */
 @ThreadSafe
-@ParametersAreNonnullByDefault
 public class ServletServiceRegisterer<T extends HttpServlet> extends ServletServiceRegistererTemplate<T> {
 
     private final Constructor<T> constructor;
