@@ -730,7 +730,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from XML file '%s': %s",
                                 file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(is);
+                            if (is != null) {
+                                Closeables.closeQuietly(is);
+                            }
                         }
                     } else {
                         Reader r = null;
@@ -741,7 +743,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from %s properties file '%s': %s",
                                 charset.displayName(), file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(r);
+                            if (r != null) {
+                                Closeables.closeQuietly(r);
+                            }
                         }
                     }
                 }
@@ -791,7 +795,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from XML file '%s': %s",
                                 file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(is);
+                            if (is != null) {
+                                Closeables.closeQuietly(is);
+                            }
                         }
                     } else {
                         Reader r = null;
@@ -802,7 +808,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from %s properties file '%s': %s",
                                 charset.displayName(), file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(r);
+                            if (r != null) {
+                                Closeables.closeQuietly(r);
+                            }
                         }
                     }
                 }
@@ -1105,7 +1113,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from XML file '%s': %s",
                                 file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(is);
+                            if (is != null) {
+                                Closeables.closeQuietly(is);
+                            }
                         }
                     } else {
                         Reader r = null;
@@ -1116,7 +1126,9 @@ public class ConfigReader {
                             throw ConfigurationExceptionCodes.IO_ERROR.create(e, String.format("unable to load properties from %s properties file '%s': %s",
                                 charset.displayName(), file.getAbsolutePath(), e.getMessage()));
                         } finally {
-                            Closeables.closeQuietly(r);
+                            if (r != null) {
+                                Closeables.closeQuietly(r);
+                            }
                         }
                     }
                 }
