@@ -49,28 +49,37 @@
 
 package com.openexchange.util.custom.config;
 
+import static com.openexchange.util.custom.base.NullUtil.absent;
+import static com.openexchange.util.custom.base.NullUtil.emptyList;
+import static com.openexchange.util.custom.base.NullUtil.emptySet;
+import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
+import static com.openexchange.util.custom.base.NullUtil.immutableSetCopyOf;
+import static com.openexchange.util.custom.base.NullUtil.optional;
+import static com.openexchange.util.custom.base.NullUtil.optionalFromNullable;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.nio.charset.Charset;
 import java.util.Iterator;
+import java.util.Objects;
+import java.util.function.Function;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
-import javax.annotation.CheckReturnValue;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
+
 import javax.mail.internet.idn.IDNA;
 import com.google.common.base.CharMatcher;
-import com.google.common.base.Function;
 import com.google.common.base.Optional;
 import com.google.common.base.Splitter;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Iterators;
+import com.openexchange.annotation.NonNull;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
 import com.openexchange.exception.OXException;
 import com.openexchange.session.Session;
+import com.openexchange.util.custom.base.NullUtil;
 
 
 /**
@@ -79,7 +88,6 @@ import com.openexchange.session.Session;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.2.0
  */
-@ParametersAreNonnullByDefault
 public class ConfigViewReader {
 
     public static ConfigViewReader ofUser(final @Nullable ConfigViewFactory configViewFactory, int userId, int contextId) throws OXException {
@@ -132,6 +140,10 @@ public class ConfigViewReader {
         public boolean equals(@Nullable Object obj) {
             return super.equals(obj);
         }
+        @Override
+        public int hashCode() {
+            return Objects.hash(prefix);
+        }
     }
     
     public static final Function<String, String> toPrefixFunction(final @Nullable String prefix) {
@@ -163,7 +175,6 @@ public class ConfigViewReader {
     }
     
     public final class MandatoryValueReader {
-        @CheckReturnValue
         public String str(final String name) throws OXException {
             final String n = n(name);
             final ConfigView cv = configView;
@@ -181,7 +192,6 @@ public class ConfigViewReader {
             return str;
         }
         
-        @CheckReturnValue
         public String str(final String name, final String defaultValue) throws OXException {
             final String n = n(name);
             final ConfigView cv = configView;
@@ -199,7 +209,6 @@ public class ConfigViewReader {
             return str;
         }
         
-        @CheckReturnValue
         public long longNum(final String name, final long defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (! str.isPresent()) {
@@ -212,7 +221,6 @@ public class ConfigViewReader {
             }
         }
 
-        @CheckReturnValue
         public long longNum(final String name) throws OXException {
             final String str = mandatory.str(name);
             try {
@@ -222,7 +230,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public int intNum(final String name, final int defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (! str.isPresent()) {
@@ -234,7 +241,7 @@ public class ConfigViewReader {
                 throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a numeric value", n(name)));
             }
         }
-        @CheckReturnValue
+
         public int intNum(final String name) throws OXException {
             final String str = mandatory.str(name);
             try {
@@ -243,7 +250,7 @@ public class ConfigViewReader {
                 throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a numeric value", n(name)));
             }
         }
-        @CheckReturnValue
+
         public int positiveIntNum(final String name) throws OXException {
             final int i = mandatory.intNum(name);
             if (i < 0) {
@@ -253,7 +260,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public boolean bool(final String name, final boolean defaultValue) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
@@ -269,7 +275,6 @@ public class ConfigViewReader {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a boolean (true/false)", n(name)));
         }
 
-        @CheckReturnValue
         public boolean bool(final String name) throws OXException {
             final String str = mandatory.str(name);
             if (str.equalsIgnoreCase("true")) {
@@ -281,7 +286,6 @@ public class ConfigViewReader {
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a boolean (true/false)", n(name)));
         }
         
-        @CheckReturnValue
         public String hostname(final String name, final String defaultValue) throws OXException {
             final String str = IDNA.toASCII(mandatory.str(name, defaultValue));
             if (str != null) {
@@ -290,7 +294,7 @@ public class ConfigViewReader {
                 return defaultValue;
             }
         }
-        @CheckReturnValue
+
         public String hostname(final String name) throws OXException {
             final String str = IDNA.toASCII(mandatory.str(name));
             if (str != null) {
@@ -300,7 +304,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public int port(final String name) throws OXException {
             final int value = mandatory.intNum(name);
             if (value <= 0 || value > 65535) {
@@ -309,7 +312,7 @@ public class ConfigViewReader {
                 return value;
             }
         }
-        @CheckReturnValue
+
         public int port(final String name, final int defaultValue) throws OXException {
             final Optional<Integer> o = optional.intNum(name);
             if (! o.isPresent()) {
@@ -323,21 +326,25 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Charset charset(final String name, final Charset defaultValue) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
                 return defaultValue;
             } else {
                 try {
-                    return Optional.fromNullable(Charset.forName(o.get())).or(defaultValue);
+                    final Charset cs = Charset.forName(o.get());
+                    if (cs != null) {
+                        return cs;
+                    } else {
+                        return defaultValue;
+                    }
                 } catch (final Exception e) {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, String.format("%s does not contain a valid charset: %s",
                         n(name), e.getMessage()));
                 }
             }
         }
-        @CheckReturnValue
+
         public Charset charset(final String name) throws OXException {
             final String str = mandatory.str(name);
             final @Nullable Charset result;
@@ -354,37 +361,38 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public ImmutableList<String> strList(final String name, final CharMatcher split) throws OXException {
             final String str = mandatory.str(name);
-            final ImmutableList<String> list = ImmutableList.copyOf(Splitter.on(split).omitEmptyStrings().split(str));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(str);
+            final ImmutableList<String> list = NullUtil.immutableCopyOf(iter);
             if (list.isEmpty()) {
                 throw ConfigurationExceptionCodes.PROPERTY_MISSING.create(n(name));
             } else {
                 return list;
             }
         }
-        @CheckReturnValue
+
         public ImmutableList<String> strList(final String name) throws OXException {
             return mandatory.strList(name, DEFAULT_SPLIT_PATTERN);
         }
         
-        @CheckReturnValue
         public ImmutableSet<String> strSet(final String name, final CharMatcher split) throws OXException {
             final String str = mandatory.str(name);
-            final ImmutableSet<String> set = ImmutableSet.copyOf(Splitter.on(split).omitEmptyStrings().split(str));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(str);
+            final ImmutableSet<String> set = NullUtil.immutableSetCopyOf(iter);
             if (set.isEmpty()) {
                 throw ConfigurationExceptionCodes.PROPERTY_MISSING.create(n(name));
             } else {
                 return set;
             }
         }
-        @CheckReturnValue
+
         public ImmutableSet<String> strSet(final String name) throws OXException {
             return mandatory.strSet(name, DEFAULT_SPLIT_PATTERN);
         }
         
-        @CheckReturnValue
         public URI uri(String name) throws OXException {
             final String str = mandatory.str(name);
             try {
@@ -394,7 +402,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public URI uri(String name, URI defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -408,7 +415,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public URI uri(String name, String defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -426,7 +432,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name) throws OXException {
             final String str = mandatory.str(name);
             final Pattern result;
@@ -442,7 +447,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name, Pattern defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -462,7 +466,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name, int flags, Pattern defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -482,7 +485,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name, String defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -512,7 +514,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name, int flags, String defaultValue) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -542,7 +543,6 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Pattern pattern(String name, int flags) throws OXException {
             final String str = mandatory.str(name);
             final Pattern result;
@@ -563,50 +563,47 @@ public class ConfigViewReader {
     public final MandatoryValueReader m = mandatory;
 
     public final class OptionalValueReader {
-        @CheckReturnValue
         public Optional<String> str(final String name) throws OXException {
             final String n = n(name);
             final ConfigView cv = configView;
             if (cv == null) {
-                return Optional.absent();
+                return absent();
             }
             String str = cv.opt(n, String.class, null);
             if (str == null) {
-                return Optional.absent();
+                return absent();
             }
             str = str.replaceAll("^\\s*", "").replaceAll("\\s*$", "");
             if (str.isEmpty()) {
-                return Optional.absent();
+                return absent();
             }
-            return Optional.of(str);
+            return optional(str);
         }
         
-        @CheckReturnValue
         public Optional<Long> longNum(final String name) throws OXException {
             final Optional<String> str = optional.str(name);
             if (! str.isPresent()) {
-                return Optional.absent();
+                return absent();
             }
             try {
-                return Optional.fromNullable(Long.parseLong(str.get()));
+                return optionalFromNullable(Long.parseLong(str.get()));
             } catch (final NumberFormatException e) {
                 throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a numeric value", n(name)));
             }
         }
 
-        @CheckReturnValue
         public Optional<Integer> intNum(final String name) throws OXException {
             final Optional<String> str = optional.str(name);
             if (! str.isPresent()) {
-                return Optional.absent();
+                return absent();
             }
             try {
-                return Optional.fromNullable(Integer.parseInt(str.get()));
+                return optionalFromNullable(Integer.parseInt(str.get()));
             } catch (final NumberFormatException e) {
                 throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a numeric value", n(name)));
             }
         }
-        @CheckReturnValue
+
         public Optional<Integer> positiveIntNum(final String name) throws OXException {
             final Optional<Integer> o = optional.intNum(name);
             if (o.isPresent()) {
@@ -618,32 +615,29 @@ public class ConfigViewReader {
             return o;
         }
         
-        @CheckReturnValue
         public Optional<Boolean> bool(final String name) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return Optional.absent();
+                return absent();
             }
             final String str = o.get();
             if (str.equalsIgnoreCase("true")) {
-                return Optional.of(true);
+                return optional(true);
             }
             if (str.equalsIgnoreCase("false")) {
-                return Optional.of(false);
+                return optional(false);
             }
             throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("%s is not a boolean (true/false)", n(name)));
         }
         
-        @CheckReturnValue
         public Optional<String> hostname(final String name) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return Optional.absent();
+                return absent();
             }
-            return Optional.fromNullable(IDNA.toASCII(o.get()));
+            return optionalFromNullable(IDNA.toASCII(o.get()));
         }
         
-        @CheckReturnValue
         public Optional<Integer> port(final String name) throws OXException {
             final Optional<Integer> i = optional.intNum(name);
             if (! i.isPresent()) {
@@ -657,14 +651,13 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public Optional<Charset> charset(final String name) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return Optional.absent();
+                return absent();
             } else {
                 try {
-                    return Optional.fromNullable(Charset.forName(o.get()));
+                    return optionalFromNullable(Charset.forName(o.get()));
                 } catch (final Exception e) {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, String.format("%s does not contain a valid charset: %s",
                         n(name), e.getMessage()));
@@ -672,114 +665,122 @@ public class ConfigViewReader {
             }
         }
         
-        @CheckReturnValue
         public ImmutableList<String> strList(final String name, final CharMatcher split, final Iterator<String> defaultValues) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableList.<String>copyOf(defaultValues);
+                return immutableCopyOf(defaultValues);
             }
-            return ImmutableList.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableList<String> strList(final String name, final Iterator<String> defaultValues) throws OXException {
             return optional.strList(name, DEFAULT_SPLIT_PATTERN, defaultValues);
         }
-        @CheckReturnValue
+        
+        @SuppressWarnings("null")
         public ImmutableList<String> strList(final String name, final CharMatcher split, final String... defaultValues) throws OXException {
             return optional.strList(name, split, Iterators.forArray(defaultValues));
         }
-        @CheckReturnValue
+        
+        @SuppressWarnings("null")
         public ImmutableList<String> strList(final String name, final String... defaultValues) throws OXException {
             return optional.strList(name, DEFAULT_SPLIT_PATTERN, Iterators.forArray(defaultValues));
         }
         
-        @CheckReturnValue
         public ImmutableList<String> strList(final String name, final CharMatcher split) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableList.of();
+                return emptyList();
             }
-            return ImmutableList.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableList<String> strList(final String name) throws OXException {
             return optional.strList(name, DEFAULT_SPLIT_PATTERN);
         }
         
-        @CheckReturnValue
         public ImmutableList<String> strList(final String name, final CharMatcher split, final Iterable<String> defaultValues) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableList.<String>copyOf(defaultValues);
+                return immutableCopyOf(defaultValues);
             }
-            return ImmutableList.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableList<String> strList(final String name, final Iterable<String> defaultValues) throws OXException {
             return optional.strList(name, DEFAULT_SPLIT_PATTERN, defaultValues);
         }
         
-        @CheckReturnValue
         public ImmutableSet<String> strSet(final String name, final CharMatcher split, final Iterator<String> defaultValues) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableSet.<String>copyOf(defaultValues);
+                return immutableSetCopyOf(defaultValues);
             }
-            return ImmutableSet.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableSetCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableSet<String> strSet(final String name, final Iterator<String> defaultValues) throws OXException {
             return optional.strSet(name, DEFAULT_SPLIT_PATTERN, defaultValues);
         }
-        @CheckReturnValue
+        
+        @SuppressWarnings("null")
         public ImmutableSet<String> strSet(final String name, final CharMatcher split, final String... defaultValues) throws OXException {
             return optional.strSet(name, split, Iterators.forArray(defaultValues));
         }
-        @CheckReturnValue
+        
+        @SuppressWarnings("null")
         public ImmutableSet<String> strSet(final String name, final String... defaultValues) throws OXException {
             return optional.strSet(name, DEFAULT_SPLIT_PATTERN, Iterators.forArray(defaultValues));
         }
         
-        @CheckReturnValue
         public ImmutableSet<String> strSet(final String name, final CharMatcher split) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableSet.of();
+                return emptySet();
             }
-            return ImmutableSet.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableSetCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableSet<String> strSet(final String name) throws OXException {
             return optional.strSet(name, DEFAULT_SPLIT_PATTERN);
         }
         
-        @CheckReturnValue
         public ImmutableSet<String> strSet(final String name, final CharMatcher split, final Iterable<String> defaultValues) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return ImmutableSet.<String>copyOf(defaultValues);
+                return immutableSetCopyOf(defaultValues);
             }
-            return ImmutableSet.copyOf(Splitter.on(split).omitEmptyStrings().split(o.get()));
+            @SuppressWarnings("null")
+            final @NonNull Iterable<String> iter = Splitter.on(split).omitEmptyStrings().split(o.get());
+            return immutableSetCopyOf(iter);
         }
-        @CheckReturnValue
+
         public ImmutableSet<String> strSet(final String name, final Iterable<String> defaultValues) throws OXException {
             return optional.strSet(name, DEFAULT_SPLIT_PATTERN, defaultValues);
         }
         
-        @CheckReturnValue
         public Optional<URI> uri(String name) throws OXException {
             final Optional<String> o = optional.str(name);
             if (! o.isPresent()) {
-                return Optional.absent();
+                return absent();
             }
             try {
-                return Optional.of(new URI(o.get()));
+                return optional(new URI(o.get()));
             } catch (final URISyntaxException e) {
                 throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, String.format("the value of %s is not a valid URI", n(name)));
             }
         }
         
-        @CheckReturnValue
         public Optional<Pattern> pattern(String name) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -790,16 +791,15 @@ public class ConfigViewReader {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, String.format("the value of %s is not a valid regular expression", n(name)));
                 }
                 if (result != null) {
-                    return Optional.of(result);
+                    return optional(result);
                 } else {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("the value of %s is not a valid regular expression (null result)", n(name)));
                 }
             } else {
-                return Optional.absent();
+                return absent();
             }
         }
         
-        @CheckReturnValue
         public Optional<Pattern> pattern(String name, int flags) throws OXException {
             final Optional<String> str = optional.str(name);
             if (str.isPresent()) {
@@ -810,18 +810,19 @@ public class ConfigViewReader {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(e, String.format("the value of %s is not a valid regular expression", n(name)));
                 }
                 if (result != null) {
-                    return Optional.of(result);
+                    return optional(result);
                 } else {
                     throw ConfigurationExceptionCodes.INVALID_CONFIGURATION.create(String.format("the value of %s is not a valid regular expression (null result)", n(name)));
                 }
             } else {
-                return Optional.absent();
+                return absent();
             }
         }
     };
     public final OptionalValueReader optional = new OptionalValueReader();
     public final OptionalValueReader o = optional;
 
+    @SuppressWarnings("null")
     public static final CharMatcher DEFAULT_SPLIT_PATTERN = CharMatcher.anyOf("\r\n;, ");
     
 }
