@@ -52,8 +52,6 @@ package com.openexchange.util.custom.i18n;
 import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
 import java.util.HashMap;
 import java.util.Map;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.PropertyFilter;
@@ -75,18 +73,13 @@ public enum PropertyTranslations {
                 notNull(ConfigurationExceptionCodes.INVALID_CONFIGURATION.create("ConfigurationService is null")));
         }
         
-        final Pattern pattern;
-        {
-            pattern = Pattern.compile("^\\Q" + propertyName + ".\\E([^_\\.]_[^_\\.])$");
-        }
-        
+        final String propertyNamePrefix = propertyName + (propertyName.endsWith(".") ? "" : ".");
         final Map<String, String> properties;
         try {
             properties = new HashMap<String, String>(configService.getProperties(new PropertyFilter() {
                 @Override
                 public boolean accept(@Nullable String name, @Nullable String value) throws OXException {
-                    return name != null && (name.equals(propertyName)
-                        || pattern.matcher(name).matches());
+                    return name != null && (name.equals(propertyName) || (name.startsWith(propertyNamePrefix) && name.length() > propertyNamePrefix.length()));
                 }
             }));
         } catch (final OXException e) {
@@ -105,16 +98,7 @@ public enum PropertyTranslations {
         for (final Map.Entry<String, String> e : properties.entrySet()) {
             final String key = e.getKey();
             if (key != null) {
-                final String lang;
-                {
-                    final Matcher m = pattern.matcher(key);
-                    if (m.matches()) {
-                        lang = m.group(1);
-                    } else {
-                        lang = null;
-                    }
-                }
-                
+                final String lang = key.length() > propertyNamePrefix.length() ? key.substring(propertyNamePrefix.length()) : null;
                 if (lang != null) {
                     final String value = e.getValue();
                     if (value == null || value.isEmpty() || value.trim().isEmpty()) {
